==> asro_preprocessing-0.1.0-py3-none-any.whl: asro_preprocessing/preprocessing.py <==
import pandas as pd
import re
from nltk.tokenize import word_tokenize
import os


class AsroPreprocessing:
    def __init__(self):
        """
        Inisialisasi class dengan menggunakan data bawaan library:
        - Stopwords: data/stopwords.txt
        - Kamus Kata Baku: data/kamuskatabaku.xlsx
        """
        base_path = os.path.dirname(__file__)

        # Load stopwords dari file bawaan library
        stopwords_path = os.path.join(base_path, "data/stopwords.txt")
        with open(stopwords_path, "r", encoding="utf-8") as f:
            self.stopwords = set(f.read().splitlines())

        # Load kamus kata baku dari file bawaan library
        normalization_path = os.path.join(base_path, "data/kamuskatabaku.xlsx")
        self.normalization_dict = pd.read_excel(normalization_path, header=None)
        self.normalization_dict = dict(zip(self.normalization_dict[0], self.normalization_dict[1]))

    @staticmethod
    def clean_text(text):
        """
        Membersihkan teks dari karakter khusus, angka, tanda baca, dan spasi berlebih.
        """
        text = re.sub(r"([@#][A-Za-z0-9]+)|(\w+:\/\/\S+)|\d+|[^\w\s]|_", " ", text)
        text = re.sub(r"\s+", " ", text)
        return text.strip()

    @staticmethod
    def tokenize_text(text):
        """
        Memecah teks menjadi daftar kata (tokenisasi).
        """
        return word_tokenize(text)

    def remove_stopwords(self, tokens):
        """
        Menghapus stopwords dari daftar token.
        """
        return [token for token in tokens if token not in self.stopwords and token.isalpha()]

    def normalize_text(self, tokens):
        """
        Normalisasi kata tidak baku menjadi kata baku menggunakan kamus.
        """
        return [self.normalization_dict.get(token, token) for token in tokens]

    def preprocess(self, input_path, text_column="comment"):
        """
        Melakukan preprocessing lengkap:
        - Membaca data dari Excel.
        - Membersihkan, tokenisasi, menghapus stopwords, dan normalisasi teks.
        - Menghapus duplikat berdasarkan kolom 'Cleaned_Text'.
        - Mengembalikan DataFrame dengan hanya kolom 'comment'.

        :param input_path: Path ke file Excel input.
        :param text_column: Nama kolom teks yang akan diproses.
        :return: DataFrame dengan kolom 'comment' yang telah diproses.
        """
        # Membaca file Excel
        df = pd.read_excel(input_path)

        # Validasi kolom teks
        if text_column not in df.columns:
            raise ValueError(f"Kolom '{text_column}' tidak ditemukan dalam DataFrame.")

        # Case folding
        df["Case_Folding"] = df[text_column].str.lower()

        # Cleaning text
        df["Cleaned_Text"] = df["Case_Folding"].apply(self.clean_text)

        # Menghapus duplikat berdasarkan 'Cleaned_Text'
        df = df.drop_duplicates(subset="Cleaned_Text", keep="first").reset_index(drop=True)

        # Tokenizing
        df["Text_Tokenizing"] = df["Cleaned_Text"].apply(self.tokenize_text)

        # Removing stopwords
        df["Filtered_Text"] = df["Text_Tokenizing"].apply(self.remove_stopwords)

        # Normalizing text
        df["Normalized_Text"] = df["Filtered_Text"].apply(self.normalize_text)

        # Menggabungkan token hasil normalisasi kembali menjadi teks
        df["comment"] = df["Normalized_Text"].apply(lambda tokens: " ".join(tokens))

        # Hanya mengembalikan kolom 'comment'
        return df[["comment"]]

==> asro_preprocessing-0.1.2-py3-none-any.whl: asro_preprocessing/preprocessing.py <==
import pandas as pd
import re
from nltk.tokenize import word_tokenize
import os

class AsroPreprocessing:
    def __init__(self):
        base_path = os.path.dirname(__file__)

        # Load stopwords dari file bawaan library
        stopwords_path = os.path.join(base_path, "data/stopwords.txt")
        with open(stopwords_path, "r", encoding="utf-8") as f:
            self.stopwords = set(f.read().splitlines())

        # Load kamus kata baku dari file bawaan library
        normalization_path = os.path.join(base_path, "data/kamuskatabaku.xlsx")
        self.normalization_dict = pd.read_excel(normalization_path, header=None)
        self.normalization_dict = dict(zip(self.normalization_dict[0], self.normalization_dict[1]))

        # Load news media dictionary
        news_dictionary_path = os.path.join(base_path, "data/news_dictionary.txt")
        with open(news_dictionary_path, "r", encoding="utf-8") as f:
            self.news_media = set(f.read().splitlines())

    @staticmethod
    def clean_text(text):
        text = re.sub(r"([@#][A-Za-z0-9]+)|(\w+:\/\/\S+)|\d+|[^\w\s]|_", " ", text)
        text = re.sub(r"\s+", " ", text)
        return text.strip()

    @staticmethod
    def tokenize_text(text):
        return word_tokenize(text)

    def remove_stopwords(self, tokens):
        return [token for token in tokens if token not in self.stopwords and token.isalpha()]

    def normalize_text(self, tokens):
        return [self.normalization_dict.get(token, token) for token in tokens]

    def detect_media_source(self, tokens):
        # Detect if tokens contain any news media names
        return any(token in self.news_media for token in tokens)

    def preprocess(self, input_path, text_column="comment", output_path="output.xlsx"):
        df = pd.read_excel(input_path)
        if text_column not in df.columns:
            raise ValueError(f"Kolom '{text_column}' tidak ditemukan dalam DataFrame.")

        df["Case_Folding"] = df[text_column].str.lower()
        df["Cleaned_Text"] = df["Case_Folding"].apply(self.clean_text)
        df = df.drop_duplicates(subset="Cleaned_Text", keep="first").reset_index(drop=True)
        df["Text_Tokenizing"] = df["Cleaned_Text"].apply(self.tokenize_text)
        df["Filtered_Text"] = df["Text_Tokenizing"].apply(self.remove_stopwords)
        df["Normalized_Text"] = df["Filtered_Text"].apply(self.normalize_text)
        df["Is_Media"] = df["Filtered_Text"].apply(self.detect_media_source)

        df.to_excel(output_path, index=False)
        return df
